@@ -5,7 +5,7 @@ use Bonobo;
 init Gnome $0, '0.1';
 init Bonobo;
 
-$factory = new Bonobo::GenericFactory (
+$factory = new Gnome::BonoboGenericFactory (
 	'OAFIID:Bonobo_perlentry_factory',
 	\&create_instance);
 
@@ -13,7 +13,7 @@ main Bonobo;
 
 sub create_instance {
 	my $widget = new Gtk::Entry;
-	my $object = new Bonobo::Control $widget;
+	my $object = new Gnome::BonoboControl $widget;
 	$widget->set_text("Hello from Bonobo/Perl!");
 	$widget->show;
 	return $object;
