@@ -7,4 +7,7 @@ typedef GnomeCanvasItem * Gnome__CanvasItem_Up;
 typedef GnomeCanvasItem * Gnome__CanvasItem_Sink_Up;
 typedef GnomeCanvasItem * Gnome__CanvasItem_OrNULL_Up;
 
+/* if must already be allocated */
+void SvGnomeUIInfo (SV *data, GnomeUIInfo *info);
+
 #endif /*_Gnome_Types_h_*/
